from __future__ import annotations

from .tool import tatsu_main

if __name__ == '__main__':
    tatsu_main()
